@@ -1,26 +1,29 @@
 from c8.api import APIWrapper
-from c8.request import Request
-from c8.response import Response
-import json
-
 from c8.exceptions import (
-    CreateAPIKey,
-    RemoveAPIKey,
-    ListDataBases,
-    DataBaseAccessLevel,
-    SetDataBaseAccessLevel,
-    ClearDataBaseAccessLevel,
-    SetCollectionAccessLevel,
-    CollectionAccessLevel,
+    BillingAccessLevel,
+    ClearBillingAccessLevel,
     ClearCollectionAccessLevel,
-    ListStreams,
-    StreamAccessLevel,
-    SetStreamAccessLevel,
+    ClearDataBaseAccessLevel,
     ClearStreamAccessLevel,
+    CollectionAccessLevel,
+    CreateAPIKey,
+    DataBaseAccessLevel,
+    GetAPIKeys,
+    GetAttributes,
+    ListDataBases,
+    ListStreams,
+    RemoveAllAttributes,
+    RemoveAPIKey,
+    RemoveAttribute,
     SetBillingAccessLevel,
-    BillingAcessLevel,
-    ClearBillingAccessLevel
+    SetCollectionAccessLevel,
+    SetDataBaseAccessLevel,
+    SetStreamAccessLevel,
+    StreamAccessLevel,
+    UpdateAttributes,
 )
+from c8.request import Request
+
 
 class APIKeys(APIWrapper):
     """Base class for API keys API wrappers.
@@ -29,38 +32,50 @@ class APIKeys(APIWrapper):
     :type connection: c8.connection.Connection
     :param executor: API executor.
     :type executor: c8.executor.Executor
-   
+
     """
 
     def __init__(self, connection, executor, keyid):
         super(APIKeys, self).__init__(connection, executor)
         self._keyid = keyid
 
-    
     def create_api_key(self):
         """Creates an api key.
-        
+
         :return: Creates an api key.
         :rtype: list
         :raise c8.exceptions.CreateAPIKey: If request fails.
         """
-        request = Request(
-            method='post',
-            endpoint='/key',
-            data={
-                    "keyid": self._keyid
-                }
-        )
+        request = Request(method="post", endpoint="/key", data={"keyid": self._keyid})
 
         def response_handler(resp):
             if not resp.is_success:
                 raise CreateAPIKey(resp, request)
             else:
                 return resp.body
-                
-        return self._execute(request, response_handler)
 
-    
+        return self._execute(request, response_handler, custom_prefix="/_api")
+
+    def get_api_key(self):
+        """Fetch details of an api key.
+        :param keyid: Id of the key to be fetched.
+        :type name: str | unicode
+        :return: Details of the api key.
+        :rtype: dict
+        :raise c8.exceptions.GetAPIKeys: If request fails.
+        """
+        request = Request(
+            method="get",
+            endpoint="/key/{}".format(self._keyid),
+        )
+
+        def response_handler(resp):
+            if not resp.is_success:
+                raise GetAPIKeys(resp, request)
+            return resp.body
+
+        return self._execute(request, response_handler, custom_prefix="/_api")
+
     def remove_api_key(self):
         """Removes an api key.
         :param keyid: Id of the key to be created.
@@ -70,43 +85,41 @@ class APIKeys(APIWrapper):
         :raise c8.exceptions.RemoveAPIKey: If request fails.
         """
         request = Request(
-            method='delete',
-            endpoint='/key/{}'.format(self._keyid),
+            method="delete",
+            endpoint="/key/{}".format(self._keyid),
         )
 
         def response_handler(resp):
             if not resp.is_success:
                 raise RemoveAPIKey(resp, request)
             else:
-                if resp.body['error'] is False:
+                if resp.body["error"] is False:
                     return True
                 else:
                     return False
-                
-        return self._execute(request, response_handler)
 
-    
+        return self._execute(request, response_handler, custom_prefix="/_api")
+
     def list_accessible_databases(self):
         """Fetch the list of databases available to the specified keyid.
- 
+
         :return: List of available databases.
         :rtype: list
         :raise c8.exceptions.ListDataBases: If request fails.
         """
         request = Request(
-            method='get',
-            endpoint='/key/{}/database'.format(self._keyid),
+            method="get",
+            endpoint="/key/{}/database".format(self._keyid),
         )
 
         def response_handler(resp):
             if not resp.is_success:
                 raise ListDataBases(resp, request)
             else:
-                return resp.body['result']
-                
-        return self._execute(request, response_handler)
+                return resp.body["result"]
+
+        return self._execute(request, response_handler, custom_prefix="/_api")
 
-    
     def get_database_access_level(self, databasename):
         """Fetch the database access level for a specific database.
 
@@ -118,21 +131,20 @@ class APIKeys(APIWrapper):
         :raise c8.exceptions.DataBaseAccessLevel: If request fails.
         """
         request = Request(
-            method='get',
-            endpoint='/key/{}/database/{}'.format(self._keyid, databasename),
+            method="get",
+            endpoint="/key/{}/database/{}".format(self._keyid, databasename),
         )
 
         def response_handler(resp):
             if not resp.is_success:
                 raise DataBaseAccessLevel(resp, request)
             else:
-                return resp.body['result']
-                
-        return self._execute(request, response_handler)
+                return resp.body["result"]
+
+        return self._execute(request, response_handler, custom_prefix="/_api")
+
+    def set_database_access_level(self, databasename, grant="ro"):
 
-    
-    def set_database_access_level(self, databasename, grant='ro'):
-       
         """Set the database access level for a specific database.
 
         :param databasename: Name of the database
@@ -146,11 +158,9 @@ class APIKeys(APIWrapper):
         :raise c8.exceptions.SetDataBaseAccessLevel: If request fails.
         """
         request = Request(
-            method='put',
-            endpoint='/key/{}/database/{}'.format(self._keyid, databasename),
-            data={
-                "grant": grant
-            }
+            method="put",
+            endpoint="/key/{}/database/{}".format(self._keyid, databasename),
+            data={"grant": grant},
         )
 
         def response_handler(resp):
@@ -158,12 +168,11 @@ class APIKeys(APIWrapper):
                 raise SetDataBaseAccessLevel(resp, request)
             else:
                 return resp.body
-                
-        return self._execute(request, response_handler)
 
-    
+        return self._execute(request, response_handler, custom_prefix="/_api")
+
     def clear_database_access_level(self, databasename):
-       
+
         """Clear the database access level for a specific database.
 
         :param databasename: Name of the database
@@ -173,25 +182,48 @@ class APIKeys(APIWrapper):
         :raise c8.exceptions.ClearDataBaseAccessLevel: If request fails.
         """
         request = Request(
-            method='delete',
-            endpoint='/key/{}/database/{}'.format(self._keyid, databasename),
-           
+            method="delete",
+            endpoint="/key/{}/database/{}".format(self._keyid, databasename),
         )
 
         def response_handler(resp):
             if not resp.is_success:
                 raise ClearDataBaseAccessLevel(resp, request)
             else:
-                if resp.body['error'] is False:
+                if resp.body["error"] is False:
                     return True
-                elif resp.body['error'] is True:
+                elif resp.body["error"] is True:
                     return False
-                
-        return self._execute(request, response_handler)
 
-#------------------------------------------------------------------------
+        return self._execute(request, response_handler, custom_prefix="/_api")
 
-    def get_collection_access_level(self, collection_name, databasename='_system'):
+    def list_accessible_collections(self, databasename="_system", full=False):
+        """Fetch all the accessible collections in a database.
+
+        :param databasename: Name of the database
+        :type databasename: string
+        :param full: Return the full set of access levels for all collections.
+        :type full: boolean
+        :return: AccessLevel of a db.
+        :rtype: string
+        :raise c8.exceptions.CollectionAccessLevel: If request fails.
+        """
+        request = Request(
+            method="get",
+            endpoint="/key/{}/database/{}/collection?full={}".format(
+                self._keyid, databasename, full
+            ),
+        )
+
+        def response_handler(resp):
+            if not resp.is_success:
+                raise CollectionAccessLevel(resp, request)
+            else:
+                return resp.body["result"]
+
+        return self._execute(request, response_handler, custom_prefix="/_api")
+
+    def get_collection_access_level(self, collection_name, databasename="_system"):
         """Fetch the collection access level for a specific collection in a database.
 
         :param collection_name: Name of the collection
@@ -203,24 +235,24 @@ class APIKeys(APIWrapper):
         :raise c8.exceptions.CollectionAccessLevel: If request fails.
         """
         request = Request(
-            method='get',
-            endpoint='/key/{}/database/{}/collection/{}'.format(self._keyid,
-                                                                     databasename,
-                                                                     collection_name),
+            method="get",
+            endpoint="/key/{}/database/{}/collection/{}".format(
+                self._keyid, databasename, collection_name
+            ),
         )
 
         def response_handler(resp):
             if not resp.is_success:
                 raise CollectionAccessLevel(resp, request)
             else:
-                return resp.body['result']
-                
-        return self._execute(request, response_handler)
+                return resp.body["result"]
+
+        return self._execute(request, response_handler, custom_prefix="/_api")
+
+    def set_collection_access_level(
+        self, collection_name, databasename="_system", grant="ro"
+    ):
 
-    
-    def set_collection_access_level(self, collection_name, databasename='_system',
-                                     grant='ro'):
-       
         """Set the collection access level for a specific collection in a database.
 
         :param collection_name: Name of the collection
@@ -236,13 +268,11 @@ class APIKeys(APIWrapper):
         :raise c8.exceptions.SetCollectionAccessLevel: If request fails.
         """
         request = Request(
-            method='put',
-            endpoint='/key/{}/database/{}/collection/{}'.format(self._keyid,
-                                                                     databasename,
-                                                                     collection_name),
-            data={
-                "grant": grant
-            }
+            method="put",
+            endpoint="/key/{}/database/{}/collection/{}".format(
+                self._keyid, databasename, collection_name
+            ),
+            data={"grant": grant},
         )
 
         def response_handler(resp):
@@ -250,12 +280,11 @@ class APIKeys(APIWrapper):
                 raise SetCollectionAccessLevel(resp, request)
             else:
                 return resp.body
-                
-        return self._execute(request, response_handler)
 
-    
-    def clear_collection_access_level(self, collection_name, databasename='_system'):
-       
+        return self._execute(request, response_handler, custom_prefix="/_api")
+
+    def clear_collection_access_level(self, collection_name, databasename="_system"):
+
         """Clear the collection access level for a specific collection in a database.
 
         :param collection_name: Name of the collection
@@ -267,29 +296,26 @@ class APIKeys(APIWrapper):
         :raise c8.exceptions.ClearCollectionAccessLevel: If request fails.
         """
         request = Request(
-            method='delete',
-            endpoint='/key/{}/database/{}/collection/{}'.format(self._keyid,
-                                                                     databasename,
-                                                                     collection_name),
-           
+            method="delete",
+            endpoint="/key/{}/database/{}/collection/{}".format(
+                self._keyid, databasename, collection_name
+            ),
         )
 
         def response_handler(resp):
             if not resp.is_success:
                 raise ClearCollectionAccessLevel(resp, request)
             else:
-                if resp.body['error'] is False:
+                if resp.body["error"] is False:
                     return True
-                elif resp.body['error'] is True:
+                elif resp.body["error"] is True:
                     return False
-                
-        return self._execute(request, response_handler)
 
-#---------------------------------------------------------------------------
+        return self._execute(request, response_handler, custom_prefix="/_api")
 
-    def list_accessible_streams(self, databasename='_system', full=False):
+    def list_accessible_streams(self, databasename="_system", full=False):
         """Fetch the list of streams available to the specified keyid.
- 
+
         :param databasename: Name of the database
         :type databasename: string
         :param full: Return the full set of access levels for all streams.
@@ -299,22 +325,21 @@ class APIKeys(APIWrapper):
         :raise c8.exceptions.ListStreams: If request fails.
         """
         request = Request(
-            method='get',
-            endpoint='/key/{}/database/{}/stream?full={}'.format(self._keyid,
-                                                                      databasename,
-                                                                      full),
+            method="get",
+            endpoint="/key/{}/database/{}/stream?full={}".format(
+                self._keyid, databasename, full
+            ),
         )
 
         def response_handler(resp):
             if not resp.is_success:
                 raise ListStreams(resp, request)
             else:
-                return resp.body['result']
-                
-        return self._execute(request, response_handler)
+                return resp.body["result"]
 
-    
-    def get_stream_access_level(self, streamname, databasename='_system', local=False):
+        return self._execute(request, response_handler, custom_prefix="/_api")
+
+    def get_stream_access_level(self, streamname, databasename="_system", local=False):
         """Fetch the database access level for a specific stream.
 
         :param streamname: Name of the stream
@@ -326,29 +351,27 @@ class APIKeys(APIWrapper):
         :raise c8.exceptions.StreamAccessLevel: If request fails.
         """
         if local is False:
-            url = '/key/{}/database/{}/stream/{}?global=True'.format(self._keyid,
-                                                                 databasename,
-                                                                 streamname)
+            url = "/key/{}/database/{}/stream/{}?global=True".format(
+                self._keyid, databasename, streamname
+            )
         elif local is True:
-            url = '/key/{}/database/{}/stream/{}?global=False'.format(self._keyid,
-                                                                 databasename,
-                                                                 streamname)
-        request = Request(
-            method='get',
-            endpoint=url
-        )
+            url = "/key/{}/database/{}/stream/{}?global=False".format(
+                self._keyid, databasename, streamname
+            )
+        request = Request(method="get", endpoint=url)
 
         def response_handler(resp):
             if not resp.is_success:
                 raise StreamAccessLevel(resp, request)
             else:
-                return resp.body['result']
-                
-        return self._execute(request, response_handler)
+                return resp.body["result"]
+
+        return self._execute(request, response_handler, custom_prefix="/_api")
+
+    def set_stream_access_level(
+        self, streamname, databasename="_system", grant="ro", local=False
+    ):
 
-    
-    def set_stream_access_level(self, streamname, databasename='_system', grant='ro', local=False):
-       
         """Set the database access level for a specific stream.
 
         :param streamname: Name of the stream
@@ -364,33 +387,28 @@ class APIKeys(APIWrapper):
         :raise c8.exceptions.SetStreamAccessLevel: If request fails.
         """
         if local is False:
-            url = '/key/{}/database/{}/stream/{}?global=True'.format(self._keyid,
-                                                                 databasename,
-                                                                 streamname)
+            url = "/key/{}/database/{}/stream/{}?global=True".format(
+                self._keyid, databasename, streamname
+            )
         elif local is True:
-            url = '/key/{}/database/{}/stream/{}?global=False'.format(self._keyid,
-                                                                 databasename,
-                                                                 streamname)
+            url = "/key/{}/database/{}/stream/{}?global=False".format(
+                self._keyid, databasename, streamname
+            )
 
-        request = Request(
-            method='put',
-            endpoint=url,
-            data={
-                "grant": grant
-            }
-        )
+        request = Request(method="put", endpoint=url, data={"grant": grant})
 
         def response_handler(resp):
             if not resp.is_success:
                 raise SetStreamAccessLevel(resp, request)
             else:
                 return resp.body
-                
-        return self._execute(request, response_handler)
 
-    
-    def clear_stream_access_level(self, streamname, databasename='_system', local=False):
-       
+        return self._execute(request, response_handler, custom_prefix="/_api")
+
+    def clear_stream_access_level(
+        self, streamname, databasename="_system", local=False
+    ):
+
         """Clear the database access level for a specific stream.
 
         :param streamname: Name of the stream
@@ -403,32 +421,26 @@ class APIKeys(APIWrapper):
         """
 
         if local is False:
-            url = '/key/{}/database/{}/stream/{}?global=True'.format(self._keyid,
-                                                                 databasename,
-                                                                 streamname)
+            url = "/key/{}/database/{}/stream/{}?global=True".format(
+                self._keyid, databasename, streamname
+            )
         elif local is True:
-            url = '/key/{}/database/{}/stream/{}?global=False'.format(self._keyid,
-                                                                 databasename,
-                                                                 streamname)
+            url = "/key/{}/database/{}/stream/{}?global=False".format(
+                self._keyid, databasename, streamname
+            )
 
-        request = Request(
-            method='delete',
-            endpoint=url
-           
-        )
+        request = Request(method="delete", endpoint=url)
 
         def response_handler(resp):
             if not resp.is_success:
                 raise ClearStreamAccessLevel(resp, request)
             else:
-                if resp.body['error'] is False:
+                if resp.body["error"] is False:
                     return True
-                elif resp.body['error'] is True:
+                elif resp.body["error"] is True:
                     return False
-                
-        return self._execute(request, response_handler)
 
-#-----------------------------------------------------------------------------
+        return self._execute(request, response_handler, custom_prefix="/_api")
 
     def get_billing_access_level(self):
         """Fetch the billing access level.
@@ -438,21 +450,20 @@ class APIKeys(APIWrapper):
         :raise c8.exceptions.BillingAccessLevel: If request fails.
         """
         request = Request(
-            method='get',
-            endpoint='/key/{}/billing'.format(self._keyid),
+            method="get",
+            endpoint="/key/{}/billing".format(self._keyid),
         )
 
         def response_handler(resp):
             if not resp.is_success:
-                raise BillingAcessLevel(resp, request)
+                raise BillingAccessLevel(resp, request)
             else:
-                return resp.body['result']
-                
-        return self._execute(request, response_handler)
+                return resp.body["result"]
+
+        return self._execute(request, response_handler, custom_prefix="/_api")
+
+    def set_billing_access_level(self, grant="ro"):
 
-    
-    def set_billing_access_level(self, grant='ro'):
-       
         """Set the collection access level for billing.
 
         :param grant   : Use "rw" to set the database access level to Administrate .
@@ -464,11 +475,9 @@ class APIKeys(APIWrapper):
         :raise c8.exceptions.SetBillingAccessLevel: If request fails.
         """
         request = Request(
-            method='put',
-            endpoint='/key/{}/billing'.format(self._keyid),
-            data={
-                "grant": grant
-            }
+            method="put",
+            endpoint="/key/{}/billing".format(self._keyid),
+            data={"grant": grant},
         )
 
         def response_handler(resp):
@@ -476,12 +485,11 @@ class APIKeys(APIWrapper):
                 raise SetBillingAccessLevel(resp, request)
             else:
                 return resp.body
-                
-        return self._execute(request, response_handler)
 
-    
+        return self._execute(request, response_handler, custom_prefix="/_api")
+
     def clear_billing_access_level(self):
-       
+
         """Clear the billing access level.
 
         :return: True if operation successful.
@@ -489,9 +497,8 @@ class APIKeys(APIWrapper):
         :raise c8.exceptions.ClearBillingAccessLevel: If request fails.
         """
         request = Request(
-            method='delete',
-            endpoint='/key/{}/billing'.format(self._keyid),
-           
+            method="delete",
+            endpoint="/key/{}/billing".format(self._keyid),
         )
 
         def response_handler(resp):
@@ -499,5 +506,89 @@ class APIKeys(APIWrapper):
                 raise ClearBillingAccessLevel(resp, request)
             else:
                 return resp.body
-                
-        return self._execute(request, response_handler)
+
+        return self._execute(request, response_handler, custom_prefix="/_api")
+
+    def get_attributes(self):
+        """Fetch the list of attributes.
+
+        :returns: All attributes for the apikey.
+        :rtype: dict
+        :raise c8.exceptions.GetAttributes: If request fails.
+        """
+        request = Request(
+            method="get",
+            endpoint="/key/{}/attributes".format(self._keyid),
+        )
+
+        def response_handler(resp):
+            if not resp.is_success:
+                raise GetAttributes(resp, request)
+            else:
+                return resp.body
+
+        return self._execute(request, response_handler, custom_prefix="/_api")
+
+    def update_attributes(self, attributes):
+        """Update the list of attributes.
+
+        :param attributes: The key-value pairs of attributes with values that needs to be updated.
+        :type attributes: dict
+        :returns: The updated attributes.
+        :rtype: Object
+        :raise c8.exceptions.UpdateAttributes: If request fails.
+        """
+        request = Request(
+            method="put",
+            endpoint="/key/{}/attributes".format(self._keyid),
+            data=attributes,
+        )
+
+        def response_handler(resp):
+            if not resp.is_success:
+                raise UpdateAttributes(resp, request)
+            else:
+                return resp.body
+
+        return self._execute(request, response_handler, custom_prefix="/_api")
+
+    def remove_all_attributes(self):
+        """Remove all attributes.
+
+        :returns: All attributes for the apikey.
+        :rtype: dict
+        :raise c8.exceptions.RemoveAllAttributes: If request fails.
+        """
+        request = Request(
+            method="delete",
+            endpoint="/key/{}/attributes/truncate".format(self._keyid),
+        )
+
+        def response_handler(resp):
+            if not resp.is_success:
+                raise RemoveAllAttributes(resp, request)
+            else:
+                return resp.body
+
+        return self._execute(request, response_handler, custom_prefix="/_api")
+
+    def remove_attribute(self, attributeid):
+
+        """Remove the specified attribute.
+
+        :returns: All attributes for the apikey.
+        :rtype: dict
+        :raise c8.exceptions.RemoveAllAttributes: If request fails.
+        """
+        request = Request(
+            method="delete",
+            endpoint="/key/{}/attributes/{}".format(self._keyid, attributeid),
+        )
+
+        def response_handler(resp):
+            if not resp.is_success:
+                raise RemoveAttribute(resp, request)
+            else:
+                return resp.body
+
+        return self._execute(request, response_handler, custom_prefix="/_api")
