@@ -1,4 +1,4 @@
-# coding=utf-8 
+# coding=utf-8
 
 from __future__ import absolute_import, unicode_literals
 
@@ -18,7 +18,8 @@ class C8ClientError(C8Error):
     :ivar message: Error message.
     :vartype message: str | unicode
     """
-    source = 'client'
+
+    source = "client"
 
     def __init__(self, msg):
         super(C8ClientError, self).__init__(msg)
@@ -62,17 +63,17 @@ class C8ServerError(C8Error):
     :ivar error_message: Raw error message from C8Db server.
     :vartype error_message: str | unicode
     """
-    source = 'server'
+
+    source = "server"
 
     def __init__(self, resp, request, msg=None):
         msg = msg or resp.error_message or resp.status_text
         self.error_message = resp.error_message
         self.error_code = resp.error_code
         if self.error_code is not None:
-            msg = '[HTTP {}][ERR {}] {}'.format(
-                resp.status_code, self.error_code, msg)
+            msg = "[HTTP {}][ERR {}] {}".format(resp.status_code, self.error_code, msg)
         else:
-            msg = '[HTTP {}] {}'.format(resp.status_code, msg)
+            msg = "[HTTP {}] {}".format(resp.status_code, msg)
         super(C8ServerError, self).__init__(msg)
         self.message = msg
         self.url = resp.url
@@ -86,15 +87,20 @@ class C8ServerError(C8Error):
 class C8AuthenticationError(C8ClientError):
     """Failed to authenticate C8 User"""
 
+
 class C8TenantNotFoundError(C8ClientError):
     """Failed to get Tenant Name"""
 
+
 class C8TokenNotFoundError(C8ClientError):
     """Failed to get Token"""
+
+
 #######################
 # Stream Exceptions #
 #######################
 
+
 class StreamProducerError(C8ClientError):
     """Failed to create Stream Producer"""
 
@@ -142,9 +148,11 @@ class StreamCommunicationError(C8ServerError):
 class StreamEventError(C8ClientError):
     """Failed to process the event from C8 stream."""
 
+
 class StreamBadInputError(C8ClientError):
     """If the request doesn’t have the expected format"""
 
+
 #######################
 # Tenant Exceptions #
 #######################
@@ -166,13 +174,18 @@ class TenantCreateError(C8ServerError):
     """Failed to create tenant."""
 
 
-class TenantUpdateError(C8ClientError):
+class TenantUpdateError(C8ServerError):
     """Failed to update tenant."""
 
 
 class TenantDeleteError(C8ServerError):
     """Failed to delete tenant."""
 
+
+class TenantDetailsError(C8ServerError):
+    """Failed to retrieve tenant details."""
+
+
 #######################
 # Topic Exceptions #
 #######################
@@ -247,6 +260,10 @@ class C8QLFunctionDeleteError(C8ServerError):
     """Failed to delete C8QL user function."""
 
 
+class C8QLGetAllBatchesError(C8ClientError):
+    """Failed to retrieve all batches for the query"""
+
+
 ##############################
 # Async Execution Exceptions #
 ##############################
@@ -298,6 +315,10 @@ class BatchExecuteError(C8ServerError):
 #########################
 
 
+class CollectionFindError(C8ClientError):
+    """Failed to retrieve collection."""
+
+
 class CollectionListError(C8ServerError):
     """Failed to retrieve collections."""
 
@@ -313,6 +334,15 @@ class CollectionDeleteError(C8ServerError):
 class CollectionTruncateError(C8ServerError):
     """Failed to truncate collection."""
 
+
+class CollectionPropertiesError(C8ServerError):
+    """Failed to retrieve collection properties."""
+
+
+class CollectionImportFromFileError(C8ClientError):
+    """Failed to load data from file"""
+
+
 #####################
 # Cursor Exceptions #
 #####################
@@ -351,10 +381,34 @@ class FabricCreateError(C8ServerError):
     """Failed to create fabric."""
 
 
+class FabricGetMetadataError(C8ServerError):
+    """Failed to get fabric information."""
+
+
+class FabricSetMetadataError(C8ServerError):
+    """Failed to set fabric metadata."""
+
+
+class FabricUpdateMetadataError(C8ServerError):
+    """Failed to update fabric metadata."""
+
+
 class FabricDeleteError(C8ServerError):
     """Failed to delete fabric."""
 
 
+class GetDcListError(C8ServerError):
+    """Failed to retrieve DC list"""
+
+
+class GetLocalDcError(C8ServerError):
+    """Failed to get local DC information"""
+
+
+class GetDcDetailError(C8ServerError):
+    """Failed to get DC details"""
+
+
 class SpotRegionUpdateError(C8ServerError):
     """Failed to update Spot Region"""
 
@@ -362,6 +416,7 @@ class SpotRegionUpdateError(C8ServerError):
 class SpotRegionAssignError(C8ServerError):
     """Fails to assign region as Spot Region"""
 
+
 #######################
 # Document Exceptions #
 #######################
@@ -480,9 +535,11 @@ class IndexCreateError(C8ServerError):
 class IndexDeleteError(C8ServerError):
     """Failed to delete collection index."""
 
+
 class GetIndexError(C8ServerError):
     """Failed to return the specified Index"""
-    
+
+
 #####################
 # Server Exceptions #
 #####################
@@ -525,10 +582,6 @@ class UserUpdateError(C8ServerError):
     """Failed to update user."""
 
 
-class UserReplaceError(C8ServerError):
-    """Failed to replace user."""
-
-
 class UserDeleteError(C8ServerError):
     """Failed to delete user."""
 
@@ -540,6 +593,7 @@ class DataBaseError(C8ServerError):
 class GetDataBaseAccessLevel(C8ServerError):
     """Failed to fetch database access level for the specified user"""
 
+
 #########################
 # Permission Exceptions #
 #########################
@@ -549,18 +603,6 @@ class PermissionListError(C8ServerError):
     """Failed to list user permissions."""
 
 
-class PermissionGetError(C8ServerError):
-    """Failed to retrieve user permission."""
-
-
-class PermissionUpdateError(C8ServerError):
-    """Failed to update user permission."""
-
-
-class PermissionResetError(C8ServerError):
-    """Failed to reset user permission."""
-
-
 #####################
 # Restql Exceptions #
 #####################
@@ -574,6 +616,10 @@ class RestqlCreateError(C8ServerError):
     """Failed to create restql."""
 
 
+class RestqlImportError(C8ServerError):
+    """Failed to import restql."""
+
+
 class RestqlDeleteError(C8ServerError):
     """Failed to delete restql."""
 
@@ -590,6 +636,10 @@ class RestqlExecuteError(C8ServerError):
     """Failed to execute restql."""
 
 
+class RestqlCursorError(C8ServerError):
+    """Failed to read next batch from cursor."""
+
+
 #######################
 # Event Exceptions #
 #######################
@@ -606,9 +656,11 @@ class EventGetError(C8ServerError):
 class EventDeleteError(C8ServerError):
     """Failed to delete the event."""
 
+
 class StreamAppGetSampleError(C8ServerError):
     """Error while retriving sample stream apps."""
 
+
 class StreamAppChangeActiveStateError(C8ServerError):
     """Error while changing active state of stream app."""
 
@@ -617,159 +669,237 @@ class StreamAppChangeActiveStateError(C8ServerError):
 # KV Exceptions #
 #######################
 
+
 class ListCollections(C8ServerError):
     """Failed to fetch the list of collections that use KV."""
 
+
 class CreateCollectionError(C8ServerError):
     """Failed to Create the given namesace/collection."""
 
+
 class DeleteCollectionError(C8ServerError):
     """Failed to Delete the given namespace/collection"""
 
+
 class InsertKVError(C8ServerError):
     """Failed to insert kv pair"""
 
+
 class DeleteEntryForKey(C8ServerError):
     """Failed to Delete entry for the specified key/keys"""
 
 
+class RemoveKVError(C8ServerError):
+    """Failed to Delete entry for all the kv pairs in the collection"""
+
+
 class GetValueError(C8ServerError):
     """Failed to fetch the value for the specified key/keys"""
 
+
 class GetKeysError(C8ServerError):
-    """Failed to get keys for the collection """
+    """Failed to get keys for the collection"""
+
 
 class GetCountError(C8ServerError):
     """Failed to get the kv count for the collection"""
 
 
+class GetKVError(C8ServerError):
+    """Failed to get all the kv pairs in the collection"""
+
+
 #######################
 # API Keys #
 #######################
 
+
 class CreateAPIKey(C8ServerError):
     """Failed to create API Key"""
 
+
 class RemoveAPIKey(C8ServerError):
     """Failed to remove API Key"""
 
+
 class GetAPIKeys(C8ServerError):
     """Failed to fetch the API keys"""
 
+
 class ListDataBases(C8ServerError):
     """Failed to fetch the databases for the specified key"""
 
+
 class DataBaseAccessLevel(C8ServerError):
     """Failed to fetch the database access level for the specified database"""
 
+
 class SetDataBaseAccessLevel(C8ServerError):
     """Failed to set the database access level for the specified database"""
 
+
 class ClearDataBaseAccessLevel(C8ServerError):
     """Failed to clear the database access level for the specified database"""
 
+
 class CollectionAccessLevel(C8ServerError):
     """Failed to fetch the database access level for the specified collection"""
 
+
 class SetCollectionAccessLevel(C8ServerError):
     """Failed to set the database access level for the specified collection"""
 
+
 class ClearCollectionAccessLevel(C8ServerError):
     """Failed to clear the database access level for the specified collection"""
 
+
 class StreamAccessLevel(C8ServerError):
     """Failed to fetch the database access level for the specified collection"""
 
+
 class SetStreamAccessLevel(C8ServerError):
     """Failed to set the database access level for the specified collection"""
 
+
 class ClearStreamAccessLevel(C8ServerError):
     """Failed to clear the database access level for the specified collection"""
 
+
 class ListStreams(C8ServerError):
     """Failed to fetch the streams for the specified key"""
 
-class BillingAcessLevel(C8ServerError):
+
+class BillingAccessLevel(C8ServerError):
     """Failed to fetch the billing access level"""
 
+
 class SetBillingAccessLevel(C8ServerError):
     """Failed to set the billing access level"""
 
+
 class ClearBillingAccessLevel(C8ServerError):
     """Failed to clear the billing access level"""
 
+
 #######################
 # Search #
 #######################
 
+
 class SearchCollectionSetError(C8ServerError):
     """Failed to set search capabilities for given collection"""
 
+
 class SearchCollectionInvalidArgument(C8ServerError):
     """Invalid arguments supplied"""
 
+
 class SearchCollectionForbiddenError(C8ServerError):
     """Permission denied for the specified collection"""
 
+
 class SearchError(C8ServerError):
     """Failed to search given search string"""
 
+
 class SearchInvalidArgumentError(C8ServerError):
     """Invalid arguments supplied"""
 
+
 class SearchForbiddenError(C8ServerError):
     """Permission denied for the specified collection"""
 
+
 class SearchNotExistError(C8ServerError):
     """Collection does not exist or search is disabled for this collection"""
 
+
 class ViewCreateError(C8ServerError):
     """Failed to create view"""
 
+
 class ViewCreateViewNameMissingError(C8ServerError):
     """The view-name is missing, then a HTTP 400 is returned."""
 
+
 class ViewCreateViewNameUnknownError(C8ServerError):
     """The view-name is unknown, then a HTTP 404 is returned."""
 
+
 class ViewGetError(C8ServerError):
     """Failed to get view information"""
 
+
 class ViewNotFoundError(C8ServerError):
     """View does not exist"""
 
+
 class ViewRenameError(C8ServerError):
     """Failed to rename view"""
 
+
 class ViewDeleteError(C8ServerError):
     """Failed to delete view"""
 
+
 class ViewGetPropertiesError(C8ServerError):
     """Failed to get properties of given view"""
 
+
 class ViewUpdatePropertiesError(C8ServerError):
     """Failed to update properties of given view"""
 
+
 class AnalyzerListError(C8ServerError):
     """Failed to get list of all available analyzers"""
 
+
 class AnalyzerCreateError(C8ServerError):
     """Failed to create analyzer"""
 
+
 class AnalyzerInvalidParametersError(C8ServerError):
     """Invalid parameters provided"""
 
+
 class AnanlyzerForbiddenError(C8ServerError):
     """User does not have permission to create analyzers"""
 
+
 class AnalyzerDeleteError(C8ServerError):
     """Failed to delete analyzer"""
 
+
 class AnalyzerGetDefinitionError(C8ServerError):
     """Failed to get analyzer definition"""
 
+
 class AnalyzerNotFoundError(C8ServerError):
     """Analyzer configuration not found"""
 
+
 class AnalyzerConflictError(C8ServerError):
     """The analyzer is still in use"""
+
+
+#######################
+# Attributes #
+#######################
+
+
+class GetAttributes(C8ServerError):
+    """Failed to fetch the Attributes for the specified user"""
+
+
+class UpdateAttributes(C8ServerError):
+    """Failed to update attributes for the specified user"""
+
+
+class RemoveAllAttributes(C8ServerError):
+    """Failed to remove all the attributes for the specified user"""
+
+
+class RemoveAttribute(C8ServerError):
+    """Failed to remove the given attribute for the specified user"""
